import {
  describe,
  expectTypeOf,
  globalExpect,
  it
} from "./chunk-FRFV7NXB.js";
import {
  World
} from "./chunk-QWOAABBK.js";
import {
  Archetype
} from "./chunk-GXV6P7V5.js";
import "./chunk-XFYQWM5B.js";

// src/archetype.test.ts
describe("Archetype", () => {
  describe("get entities()", () => {
    it("returns an entity iterator", () => {
      const world = new World();
      const archetype = new Archetype({
        world,
        entities: /* @__PURE__ */ new Set(),
        components: ["color"]
      });
      world.createEntity({ color: "red" });
      world.createEntity({ color: "blue" });
      globalExpect(archetype.entities).toBeInstanceOf(Object);
      expectTypeOf(archetype.entities).toEqualTypeOf();
    });
  });
  describe("matches()", () => {
    it("should correctly check if an entity matches the archetype", () => {
      const world = new World();
      const archetype = new Archetype({
        world,
        entities: /* @__PURE__ */ new Set(),
        components: ["color"]
      });
      const entity = world.createEntity({ color: "red" });
      globalExpect(archetype.matches(entity)).toBe(true);
    });
    it("should correctly check if an entity does not match the archetype", () => {
      const world = new World();
      const archetype = new Archetype({
        world,
        entities: /* @__PURE__ */ new Set(),
        components: ["color"],
        without: ["tagPlayer"]
      });
      const entity = world.createEntity();
      const entity2 = world.createEntity({ color: "red", tagPlayer: true });
      globalExpect(archetype.matches(entity)).toBe(false);
      globalExpect(archetype.matches(entity2)).toBe(false);
    });
  });
  describe("without()", () => {
    it("should correctly create a new archetype ignoring entities with components", () => {
      const world = new World();
      const entity = world.createEntity({
        color: "red",
        rectangle: { width: 10, height: 10 },
        transform: { position: { x: 0, y: 0 } },
        tagPlayer: true
      });
      const entity2 = world.createEntity({
        color: "blue",
        rectangle: { width: 10, height: 10 },
        transform: { position: { x: 0, y: 0 } }
      });
      const renderables = world.archetype("color", "rectangle", "transform");
      globalExpect(world.archetypes.size).toBe(1);
      globalExpect(renderables.entities.size).toBe(2);
      globalExpect(renderables.entities.has(entity)).toBe(true);
      globalExpect(renderables.entities.has(entity2)).toBe(true);
      const nonPlayerRenderables = renderables.without("tagPlayer");
      globalExpect(world.archetypes.size).toBe(2);
      expectTypeOf(nonPlayerRenderables.entities).toMatchTypeOf();
      globalExpect(nonPlayerRenderables.entities.size).toBe(1);
      globalExpect(nonPlayerRenderables.entities.has(entity)).toBe(false);
      globalExpect(nonPlayerRenderables.entities.has(entity2)).toBe(true);
      world.addEntityComponents(entity2, "tagPlayer", true);
      globalExpect(renderables.entities.size).toBe(2);
      globalExpect(nonPlayerRenderables.entities.size).toBe(0);
    });
  });
});
